# eric7.MicroPython.MicroPythonWebreplUrlsConfigDialog

Module implementing a dialog to edit the list of configured WebREPL URLs.

### Global Attributes

None

### Classes

MicroPythonWebreplUrlsConfigDialog | Class implementing a dialog to edit the list of configured WebREPL URLs.

### Functions

None

## MicroPythonWebreplUrlsConfigDialog

Class implementing a dialog to edit the list of configured WebREPL URLs.

### Derived from

QDialog, Ui_MicroPythonWebreplUrlsConfigDialog

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonWebreplUrlsConfigDialog | Constructor
__definedNames | Private method to get a list of defined connection names.
__resizeColumns | Private slot to resize the columns to their contents.
__sortItems | Private slot to sort the list by name column (i.e.
__updateActionButtons | Private slot to change the enabled state of the action buttons.
getWebreplDict | Public method to retrieve a dictionary containing the configured WebREPL URLs.
on_addButton_clicked | Private slot to add a new WebREPL connection.
on_editButton_clicked | Private slot to edit the selected WebREPL connection.
on_removeAllButton_clicked | Private slot to remove all entries.
on_removeButton_clicked | Private slot to remove the selected entries.

### Static Methods

None

#### MicroPythonWebreplUrlsConfigDialog (Constructor)

MicroPythonWebreplUrlsConfigDialog(webreplDict, parent=None)

Constructor

webreplDict (dict)
  dictionary containing the configured WebREPL URLs
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### MicroPythonWebreplUrlsConfigDialog.__definedNames

__definedNames()

Private method to get a list of defined connection names.

Return:
  list of defined connection names

Return Type:
  list of str

#### MicroPythonWebreplUrlsConfigDialog.__resizeColumns

__resizeColumns()

Private slot to resize the columns to their contents.

#### MicroPythonWebreplUrlsConfigDialog.__sortItems

__sortItems()

Private slot to sort the list by name column (i.e. column 0).

#### MicroPythonWebreplUrlsConfigDialog.__updateActionButtons

__updateActionButtons()

Private slot to change the enabled state of the action buttons.

#### MicroPythonWebreplUrlsConfigDialog.getWebreplDict

getWebreplDict()

Public method to retrieve a dictionary containing the configured WebREPL URLs.

Return:
  dictionary containing the configured WebREPL URLs

Return Type:
  dict

#### MicroPythonWebreplUrlsConfigDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to add a new WebREPL connection.

#### MicroPythonWebreplUrlsConfigDialog.on_editButton_clicked

on_editButton_clicked()

Private slot to edit the selected WebREPL connection.

#### MicroPythonWebreplUrlsConfigDialog.on_removeAllButton_clicked

on_removeAllButton_clicked()

Private slot to remove all entries.

#### MicroPythonWebreplUrlsConfigDialog.on_removeButton_clicked

on_removeButton_clicked()

Private slot to remove the selected entries.

Up